/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(a);
ADDSYMBOL(b);
ADDSYMBOL(check);
ADDSYMBOL(clear);
ADDSYMBOL(close);
ADDSYMBOL(comment);
ADDSYMBOL(delete);
ADDSYMBOL(digits);
ADDSYMBOL(eof);
ADDSYMBOL(eol);
ADDSYMBOL(error);
ADDSYMBOL(f);
ADDSYMBOL(flush);
ADDSYMBOL(from);
ADDSYMBOL(getc);
ADDSYMBOL(input);
ADDSYMBOL(mktemp);
ADDSYMBOL(mode);
ADDSYMBOL(name);
ADDSYMBOL(output);
ADDSYMBOL(pos);
ADDSYMBOL(precision);
ADDSYMBOL(rename);
ADDSYMBOL(s);
ADDSYMBOL(seek);
ADDSYMBOL(seekeof);
ADDSYMBOL(tell);
ADDSYMBOL(to);
ADDSYMBOL(update);
