/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(_strokepath);
ADDSYMBOL(_texpath);
ADDSYMBOL(align);
ADDSYMBOL(f);
ADDSYMBOL(g);
ADDSYMBOL(label);
ADDSYMBOL(labels);
ADDSYMBOL(p);
ADDSYMBOL(position);
ADDSYMBOL(s);
ADDSYMBOL(size);
ADDSYMBOL(t);
ADDSYMBOL(texsize);
ADDSYMBOL(textpath);
