/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(AND);
ADDSYMBOL(CLZ);
ADDSYMBOL(CTZ);
ADDSYMBOL(Ceil);
ADDSYMBOL(Floor);
ADDSYMBOL(Jn);
ADDSYMBOL(NOT);
ADDSYMBOL(OR);
ADDSYMBOL(Round);
ADDSYMBOL(XOR);
ADDSYMBOL(Yn);
ADDSYMBOL(a);
ADDSYMBOL(abs);
ADDSYMBOL(atan2);
ADDSYMBOL(b);
ADDSYMBOL(bitreverse);
ADDSYMBOL(bits);
ADDSYMBOL(c);
ADDSYMBOL(ceil);
ADDSYMBOL(choose);
ADDSYMBOL(cubicroots);
ADDSYMBOL(d);
ADDSYMBOL(erf);
ADDSYMBOL(erfc);
ADDSYMBOL(factorial);
ADDSYMBOL(floor);
ADDSYMBOL(fmod);
ADDSYMBOL(gamma);
ADDSYMBOL(hypot);
ADDSYMBOL(k);
ADDSYMBOL(n);
ADDSYMBOL(popcount);
ADDSYMBOL(quadraticroots);
ADDSYMBOL(quotient);
ADDSYMBOL(rand);
ADDSYMBOL(remainder);
ADDSYMBOL(round);
ADDSYMBOL(seed);
ADDSYMBOL(sgn);
ADDSYMBOL(srand);
ADDSYMBOL(unitrand);
ADDSYMBOL(x);
ADDSYMBOL(y);
ADDSYMBOL(z);
