/*****
 * This file is automatically generated by findsym.py
 * Changes will be overwritten.
 *****/

// If the ADDSYMBOL macro is not already defined, define it with the default
// purpose of referring to an external pre-translated symbol, such that
// SYM(name) also refers to that symbol.
#ifndef ADDSYMBOL
    #define ADDSYMBOL(name) extern sym::symbol PRETRANSLATED_SYMBOL_##name
    #define SYM(name) PRETRANSLATED_SYMBOL_##name
#endif

ADDSYMBOL(_cputime);
ADDSYMBOL(_eval);
ADDSYMBOL(a);
ADDSYMBOL(abort);
ADDSYMBOL(adjust);
ADDSYMBOL(angle);
ADDSYMBOL(arclength);
ADDSYMBOL(assert);
ADDSYMBOL(asydir);
ADDSYMBOL(atleast);
ADDSYMBOL(b);
ADDSYMBOL(basealign);
ADDSYMBOL(bezier);
ADDSYMBOL(blend);
ADDSYMBOL(byte);
ADDSYMBOL(byteinv);
ADDSYMBOL(c);
ADDSYMBOL(cd);
ADDSYMBOL(cmyk);
ADDSYMBOL(colorless);
ADDSYMBOL(colors);
ADDSYMBOL(colorspace);
ADDSYMBOL(controlSpecifier);
ADDSYMBOL(curlSpecifier);
ADDSYMBOL(cyclic);
ADDSYMBOL(d);
ADDSYMBOL(defaultpen);
ADDSYMBOL(dirSpecifier);
ADDSYMBOL(embedded);
ADDSYMBOL(exit);
ADDSYMBOL(f);
ADDSYMBOL(fillrule);
ADDSYMBOL(font);
ADDSYMBOL(fontcommand);
ADDSYMBOL(fontsize);
ADDSYMBOL(g);
ADDSYMBOL(gamma);
ADDSYMBOL(gray);
ADDSYMBOL(hex);
ADDSYMBOL(identity);
ADDSYMBOL(imports);
ADDSYMBOL(interactive);
ADDSYMBOL(interactivewrite);
ADDSYMBOL(interp);
ADDSYMBOL(inverse);
ADDSYMBOL(invisible);
ADDSYMBOL(isnan);
ADDSYMBOL(isometry);
ADDSYMBOL(k);
ADDSYMBOL(length);
ADDSYMBOL(linecap);
ADDSYMBOL(linejoin);
ADDSYMBOL(lineskip);
ADDSYMBOL(linetype);
ADDSYMBOL(linewidth);
ADDSYMBOL(list);
ADDSYMBOL(locale);
ADDSYMBOL(location);
ADDSYMBOL(m);
ADDSYMBOL(makepen);
ADDSYMBOL(max);
ADDSYMBOL(microseconds);
ADDSYMBOL(min);
ADDSYMBOL(miterlimit);
ADDSYMBOL(n);
ADDSYMBOL(nib);
ADDSYMBOL(offset);
ADDSYMBOL(opacity);
ADDSYMBOL(overwrite);
ADDSYMBOL(p);
ADDSYMBOL(pattern);
ADDSYMBOL(point);
ADDSYMBOL(r);
ADDSYMBOL(reflect);
ADDSYMBOL(resetdefaultpen);
ADDSYMBOL(reverse);
ADDSYMBOL(rgb);
ADDSYMBOL(rotate);
ADDSYMBOL(s);
ADDSYMBOL(scale);
ADDSYMBOL(seconds);
ADDSYMBOL(shift);
ADDSYMBOL(shiftless);
ADDSYMBOL(size);
ADDSYMBOL(slant);
ADDSYMBOL(sleep);
ADDSYMBOL(spec);
ADDSYMBOL(system);
ADDSYMBOL(t);
ADDSYMBOL(tensionSpecifier);
ADDSYMBOL(tin);
ADDSYMBOL(tok);
ADDSYMBOL(tout);
ADDSYMBOL(transform);
ADDSYMBOL(uptodate);
ADDSYMBOL(usleep);
ADDSYMBOL(view);
ADDSYMBOL(x);
ADDSYMBOL(xasyKEY);
ADDSYMBOL(xscale);
ADDSYMBOL(y);
ADDSYMBOL(yscale);
ADDSYMBOL(z);
ADDSYMBOL(zin);
ADDSYMBOL(zout);
